@@ -3,7 +3,7 @@ package Netstack::Utils::Cache;
 #------------------------------------------------------------------------------
 # 加载扩展模块功能
 #------------------------------------------------------------------------------
-use 5.016;
+use 5.018;
 use Moose;
 use namespace::autoclean;
 
@@ -17,7 +17,7 @@ has cache => (
 );
 
 #------------------------------------------------------------------------------
-# get 加载缓存对象
+# get 获取缓存数据 | 查询特定的缓存对象
 #------------------------------------------------------------------------------
 sub get {
   my $self = shift;
@@ -25,19 +25,18 @@ sub get {
 }
 
 #------------------------------------------------------------------------------
-# set 设置缓存
+# set 设置缓存数据 | 设置特定的缓存对象
 #------------------------------------------------------------------------------
 sub set {
   my $self = shift;
-  # 入参检查，异常拦截
-  confess "ERROR: must have at least one key and one value" if @_ < 2;
-  # 截取最后的键值对
-  my $lastValue = pop;
-  my $lastKey   = pop;
-
-  my @keys = @_;
+  confess __PACKAGE__ . " ERROR: 必须提供键值对" if @_ < 2;
+  # 初始化变量
+  my $value   = pop;
+  my $lastKey = pop;
+  my @keys    = @_;
+  my $ref     = $self->cache;
+  # 提供2个以上入参
   my @step;
-  my $ref = $self->cache;
   while ( my $key = shift @keys ) {
     push @step, $key;
     if ( not exists $ref->{$key} ) {
@@ -48,11 +47,11 @@ sub set {
       confess "ERROR: cache->" . join( '->', @step ) . " not a valid HashRef";
     }
   }
-  $ref->{$lastKey} = $lastValue;
+  $ref->{$lastKey} = $value;
 }
 
 #------------------------------------------------------------------------------
-# clear 清除缓存键值对
+# clear 清楚缓存数据
 #------------------------------------------------------------------------------
 sub clear {
   my $self = shift;
@@ -65,25 +64,25 @@ sub clear {
     }
   }
   else {
-    $self->cache = {};
+    $self->{cache} = {};
   }
 }
 
 #------------------------------------------------------------------------------
-# locate 加载缓存 | 此处不会自动去重
+# locate 加载缓存,，只支持单值索引 | 加载特定的缓存对象
 #------------------------------------------------------------------------------
 sub locate {
   my $self = shift;
+  # 初始化变量
   my @keys = @_;
   my $ref  = $self->cache;
-
-  # 检查是否存在缓存
+  # 遍历待查询的 keyStr
   while ( my $key = shift @keys ) {
-    return if not exists $ref->{$key};
+    if ( not exists $ref->{$key} ) {
+      return;
+    }
     $ref = $ref->{$key};
   }
-
-  # 返回计算结果
   return $ref;
 }
 
